{% extends 'base.html' %}
{% load i18n %}

{% block bodyclass %}{{ page.document_class|default:block.super }}{% endblock bodyclass %}
{% block title %}{{ page.name }}{% endblock title %}

{% block main %}

{{ page.content_html }}

{% endblock main %}

{% block context_menu %}
{% if request.user.is_superuser %}
<li><a href="{% url 'pages-page-edit' page.id %}">{% trans "Edit" %}</a></li>
{% endif %}
{% endblock %}
